       IDENTIFICATION DIVISION.                                           
       PROGRAM-ID.     AMORTIZ2.                                          
       AUTHOR.         ROGER COLE.                                        
       DATE-WRITTEN.                                                      
       DATE-COMPILED.                                                     
      *REMARKS.                                                           
      *                                                                    
      *    THIS PROGRAM WILL PRODUCE AN AMORTIZATION SCHEDULE BASED
      *    UPON PARAMETER FILE INPUT.  (ORIGINALLY WRITTEN IN BURROUGHS
      *    COBOL IN 1976 WHEN INPUT WAS STILL ON REAL 80-COLUMN CARDS).
      *    CONVERTED TO COBOL650 FOR THE PC IN DECEMBER, 2001.  THIS
      *    VERSION REFLECTS A MORE MODERN MODULAR STYLE OF PROGRAMMING.
      *                                                                    
       ENVIRONMENT DIVISION.
       CONFIGURATION SECTION.                                             
       SPECIAL-NAMES.                                                     
       INPUT-OUTPUT SECTION.                                              
       FILE-CONTROL.                                                      
           SELECT CARD-FILE            ASSIGN TO DISK
                                       ORGANIZATION IS LINE SEQUENTIAL.
           SELECT PRINT-FILE           ASSIGN TO PRINTER.      
                                                                          
       DATA DIVISION.                                                     
       FILE SECTION.                                                      
       FD  CARD-FILE
           LABEL RECORDS ARE STANDARD
           VALUE OF FILE-ID IS "AMORTIZE.INP".
       01  REQUEST-CARD.                                                   
           05  ORIG-PRIN               PIC 9(06)V99.
           05  FILLER                  PIC X(01).
           05  MTH-PAYMENT             PIC 9(04)V99.
           05  FILLER                  PIC X(01).
           05  ANN-INT-RATE            PIC 9(02)V99999.
           05  FILLER                  PIC X(01).
           05  NO-OF-MTHS              PIC 9(03).
           05  FILLER                  PIC X(01).
           05  START-MTH               PIC 9(02).
           05  FILLER                  PIC X(01).
           05  START-YEAR              PIC 9(04).
           05  FILLER                  PIC X(01).
           05  DESC-INFO               PIC X(44).
                                                                          
       FD  PRINT-FILE                                                     
           LABEL RECORDS ARE OMITTED.                                            
       01  PRINTFILE-RECORD            PIC X(132).                                                  
                                                                          
       WORKING-STORAGE SECTION.                                           

       77  END-OF-INPUT                PIC X(01)           VALUE "N".
       77  PAGE-INDICATOR              PIC 9(02)    COMP-3 VALUE ZERO.       
       77  PAY-TO-DATE                 PIC 9(06)V99 COMP-3 VALUE ZERO.       
       77  INT-TO-DATE                 PIC 9(06)V99 COMP-3 VALUE ZERO.
       77  PRIN-TO-DATE                PIC 9(06)V99 COMP-3 VALUE ZERO.
       77  PAY-FOR-YR                  PIC 9(06)V99 COMP-3 VALUE ZERO.
       77  INT-FOR-YR                  PIC 9(06)V99 COMP-3 VALUE ZERO.
       77  PRIN-FOR-YR                 PIC 9(06)V99 COMP-3 VALUE ZERO.
       01  DETAIL-1.
           05  FILLER                  PIC X(05).
           05  MTH-NAME                PIC X(10).
           05  FILLER                  PIC X(05).
           05  BEG-PRIN                PIC ZZZ,ZZ9.99.
           05  FILLER                  PIC X(01).
           05  MTH-PAY                 PIC ZZZ,ZZ9.99.
           05  FILLER                  PIC X(02).
           05  INT-AMT                 PIC ZZZ,ZZ9.99.
           05  FILLER                  PIC X(02).
           05  PRIN-AMT                PIC ZZZ,ZZ9.99.
           05  FILLER                  PIC X(05).
           05  REM-PRIN                PIC ZZZ,ZZ9.99.
       01  HEADING-1.
           05  FILLER                  PIC X(26) VALUE SPACES.
           05  H-DESC                  PIC X(44).
       01  HEADING-2.
           05  FILLER                  PIC X(21) VALUE SPACES.
           05  FILLER                  PIC X(09) VALUE 'BEGINNING'.
           05  FILLER                  PIC X(04) VALUE SPACES.
           05  FILLER                  PIC X(07) VALUE 'MONTHLY'.
           05  FILLER                  PIC X(05) VALUE SPACES.
           05  FILLER                  PIC X(12) VALUE '**** APPLIED'.
           05  FILLER                  PIC X(08) VALUE ' TO ****'.
           05  FILLER                  PIC X(05) VALUE SPACES.
           05  FILLER                  PIC X(09) VALUE 'REMAINING'.
       01  HEADING-3.
           05  FILLER                  PIC X(07) VALUE SPACES.
           05  FILLER                  PIC X(05) VALUE 'MONTH'.
           05  FILLER                  PIC X(09) VALUE SPACES.
           05  FILLER                  PIC X(09) VALUE 'PRINCIPAL'.
           05  FILLER                  PIC X(04) VALUE SPACES.
           05  FILLER                  PIC X(07) VALUE 'PAYMENT'.
           05  FILLER                  PIC X(05) VALUE SPACES.
           05  FILLER                  PIC X(10) VALUE 'INTEREST  '.
           05  FILLER                  PIC X(10) VALUE ' PRINCIPAL'.
           05  FILLER                  PIC X(05) VALUE SPACES.
           05  FILLER                  PIC X(09) VALUE 'PRINCIPAL'.
       01  YEAR-SUBHEADING.
           05  FILLER                  PIC X(05) VALUE SPACES.
           05  FILLER                  PIC X(34) VALUE ALL '*'.
           05  FILLER                  PIC X(02) VALUE SPACES.
           05  NEW-YR                  PIC 9(04).
           05  FILLER                  PIC X(02) VALUE SPACES.
           05  FILLER                  PIC X(33) VALUE ALL '*'.
       01  WORKING-AMOUNTS.
           05  PRINCIPAL-AMOUNT        PIC 9(06)V99 COMP-3 VALUE ZERO.
           05  PAYMENT-AMOUNT          PIC 9(04)V99 COMP-3 VALUE ZERO.
           05  MONTHLY-INTEREST-RATE   PIC 9(2)V9(11) COMP-3 VALUE ZERO.
           05  NO-OF-MONTHS            PIC 9(03)    COMP-3 VALUE ZERO.
           05  CURRENT-MONTH           PIC 9(02)    COMP-3 VALUE ZERO.
           05  CURRENT-YEAR            PIC 9(04)    COMP-3 VALUE ZERO.
           05  WORK-INT                PIC 9(04)V99 COMP-3 VALUE ZERO.
           05  WORK-PRIN               PIC 9(04)V99 COMP-3 VALUE ZERO.
           05  TOTAL-INTEREST-PAID     PIC 9(06)V99 COMP-3 VALUE ZERO.
       01  NAME-MONTH-ARRAY.
           05  MONTHS-A.
               10  FILLER              PIC X(10) VALUE 'JANUARY   '.
               10  FILLER              PIC X(10) VALUE 'FEBRUARY  '.
               10  FILLER              PIC X(10) VALUE 'MARCH     '.
               10  FILLER              PIC X(10) VALUE 'APRIL     '.
               10  FILLER              PIC X(10) VALUE 'MAY       '.
               10  FILLER              PIC X(10) VALUE 'JUNE      '.
               10  FILLER              PIC X(10) VALUE 'JULY      '.
               10  FILLER              PIC X(10) VALUE 'AUGUST    '.
               10  FILLER              PIC X(10) VALUE 'SEPTEMBER '.
               10  FILLER              PIC X(10) VALUE 'OCTOBER   '.
               10  FILLER              PIC X(10) VALUE 'NOVEMBER  '.
               10  FILLER              PIC X(10) VALUE 'DECEMBER  '.
           05  MONTHS-B REDEFINES MONTHS-A.
               10  MONTHLYS OCCURS 12 TIMES.
                   15  MONTH-NAME      PIC X(10).
                                                                          
       PROCEDURE DIVISION.                                                
       A000.

           PERFORM A100-INITIALIZE THRU A199-EXIT.
           IF  END-OF-INPUT = "N"
               PERFORM C100-PROCESS-PAYMENTS THRU C199-EXIT
                   UNTIL PRINCIPAL-AMOUNT = ZERO.
           PERFORM W100-CLOSE-FILES THRU W199-EXIT.
           STOP RUN.




       A100-INITIALIZE.

           OPEN INPUT CARD-FILE.                                          
           OPEN OUTPUT PRINT-FILE.
           PERFORM R100-READ-CARD-FILE THRU R199-EXIT.
           IF  END-OF-INPUT = "Y"
               GO TO A199-EXIT.
           MOVE SPACES TO DETAIL-1.
           MOVE 3 TO PAGE-INDICATOR.
           MOVE ZERO TO INT-TO-DATE, PRIN-TO-DATE, PAY-TO-DATE.
           MOVE ORIG-PRIN TO PRINCIPAL-AMOUNT.
           MOVE MTH-PAYMENT TO PAYMENT-AMOUNT.
           COMPUTE MONTHLY-INTEREST-RATE ROUNDED =
               ANN-INT-RATE / 12.
           MOVE NO-OF-MTHS TO NO-OF-MONTHS.
           MOVE START-MTH TO CURRENT-MONTH.
           MOVE START-YEAR TO CURRENT-YEAR.
           MOVE DESC-INFO TO H-DESC.
           PERFORM H100-PRINT-HEADING THRU H199-EXIT.
           PERFORM D100-NEW-YEAR THRU D199-EXIT.

       A199-EXIT.
           EXIT.




       C100-PROCESS-PAYMENTS.

           COMPUTE WORK-INT ROUNDED =
               PRINCIPAL-AMOUNT * MONTHLY-INTEREST-RATE / 100.
           IF  PRINCIPAL-AMOUNT < PAYMENT-AMOUNT
               COMPUTE PAYMENT-AMOUNT = WORK-INT + PRINCIPAL-AMOUNT
               COMPUTE WORK-PRIN = PRINCIPAL-AMOUNT
           ELSE
               COMPUTE WORK-PRIN = PAYMENT-AMOUNT - WORK-INT.
           MOVE MONTH-NAME (CURRENT-MONTH) TO MTH-NAME.
           MOVE PRINCIPAL-AMOUNT TO BEG-PRIN.
           MOVE PAYMENT-AMOUNT TO MTH-PAY.
           MOVE WORK-INT TO INT-AMT.
           MOVE WORK-PRIN TO PRIN-AMT.
           SUBTRACT WORK-PRIN FROM PRINCIPAL-AMOUNT.
           MOVE PRINCIPAL-AMOUNT TO REM-PRIN.
           WRITE PRINTFILE-RECORD FROM DETAIL-1 AFTER 1 LINES.
           ADD 1 TO CURRENT-MONTH.
           ADD WORK-INT TO INT-FOR-YR.
           ADD WORK-INT TO INT-TO-DATE.
           ADD WORK-PRIN TO PRIN-FOR-YR.
           ADD WORK-PRIN TO PRIN-TO-DATE.
           ADD PAYMENT-AMOUNT TO PAY-FOR-YR.
           ADD PAYMENT-AMOUNT TO PAY-TO-DATE.
           IF  CURRENT-MONTH > 12
               MOVE 1 TO CURRENT-MONTH
               ADD 1 TO CURRENT-YEAR
               PERFORM D200-YEAR-TOTALS THRU D299-EXIT
               PERFORM H100-PRINT-HEADING THRU H199-EXIT
               PERFORM D100-NEW-YEAR THRU D199-EXIT.
           IF  PRINCIPAL-AMOUNT = ZERO
               PERFORM D200-YEAR-TOTALS THRU D299-EXIT.
 
       C199-EXIT.
           EXIT.




       D100-NEW-YEAR.

           MOVE CURRENT-YEAR TO NEW-YR.
           WRITE PRINTFILE-RECORD FROM YEAR-SUBHEADING AFTER 2 LINES.
           MOVE SPACES TO PRINTFILE-RECORD.
           WRITE PRINTFILE-RECORD AFTER 1 LINES.
           MOVE ZERO TO INT-FOR-YR, PRIN-FOR-YR, PAY-FOR-YR.

       D199-EXIT.
           EXIT.




       D200-YEAR-TOTALS.

           MOVE SPACES TO PRINTFILE-RECORD.
           WRITE PRINTFILE-RECORD AFTER 1 LINES.
           MOVE SPACES TO DETAIL-1.
           MOVE 'THIS YEAR' TO MTH-NAME.
           MOVE PAY-FOR-YR TO MTH-PAY.
           MOVE INT-FOR-YR TO INT-AMT.
           MOVE PRIN-FOR-YR TO PRIN-AMT.
           WRITE PRINTFILE-RECORD FROM DETAIL-1 AFTER 1 LINES.
           MOVE SPACES TO DETAIL-1.
           MOVE ' TO DATE ' TO MTH-NAME.
           MOVE PAY-TO-DATE TO MTH-PAY.
           MOVE INT-TO-DATE TO INT-AMT.
           MOVE PRIN-TO-DATE TO PRIN-AMT.
           WRITE PRINTFILE-RECORD FROM DETAIL-1 AFTER 1 LINES.

       D299-EXIT.
           EXIT.




       H100-PRINT-HEADING.

           IF  PAGE-INDICATOR = 3
               NEXT SENTENCE
           ELSE
               ADD 1 TO PAGE-INDICATOR
               GO TO H199-EXIT.
           WRITE PRINTFILE-RECORD FROM HEADING-1 AFTER ADVANCING PAGE.
           WRITE PRINTFILE-RECORD FROM HEADING-2 AFTER 2 LINES.
           WRITE PRINTFILE-RECORD FROM HEADING-3 AFTER 1 LINES.
           MOVE 1 TO PAGE-INDICATOR.

       H199-EXIT.
           EXIT.



       R100-READ-CARD-FILE.

           READ CARD-FILE
               AT END MOVE "Y" TO END-OF-INPUT.

       R199-EXIT.
           EXIT.




       W100-CLOSE-FILES.
           CLOSE CARD-FILE.
           CLOSE PRINT-FILE.

       W199-EXIT.
           EXIT.
                                                                          
