       IDENTIFICATION DIVISION.                                           
       PROGRAM-ID.     DUMPMSTR.                                          
       AUTHOR.         ROGER COLE.                                        
       DATE-WRITTEN.                                                      
       DATE-COMPILED.                                                     
      *REMARKS.                                                           
      *
      *    THIS PROGRAM TAKES AN INDEXED MASTER FILE AND WRITES THE
      *    DATA TO A LINE SEQUENTIAL TEXT FILE.  THIS PROGRAM CAN BE
      *    USED FOR BACKING UP A MASTER FILE.
      *
      *    SINCE IT PRODUCES AN ORDERED TEXT FILE OF THE MASTER FILE
      *    DATA FILE, THAT DATA CAN BE TAKEN INTO THE LOADMSTR PROGRAM
      *    TO REBUILD A MASTER FILE.
      *                                                                    
       ENVIRONMENT DIVISION.
       CONFIGURATION SECTION.                                             
       SPECIAL-NAMES.                                                     
       INPUT-OUTPUT SECTION.                                              
       FILE-CONTROL.                                                      
           SELECT OUTPUT-FILE          ASSIGN TO DISK
                                       ORGANIZATION IS LINE SEQUENTIAL.
           SELECT MASTER-FILE          ASSIGN TO DISK
                                       FILE STATUS IS FILE-STAT
                                       ACCESS MODE IS SEQUENTIAL
                                       ORGANIZATION IS INDEXED
                                       RECORD KEY IS OURSTUFF-KEY.
                                                                          
       DATA DIVISION.                                                     
       FILE SECTION.                                                      
       FD  OUTPUT-FILE
           LABEL RECORDS ARE STANDARD
           VALUE OF FILE-ID IS "OURSTUFF.INP".
       01  OUTPUT-RECORD.                                                   
           05  OUTPUT-KEY.                                              
               10  OUTPUT-CLASS        PIC  X(03).
               10  OUTPUT-SEQUENCE     PIC  9(03).
           05  FILLER                  PIC  X(74).                        
                                                                          
       FD  MASTER-FILE                                                     
           LABEL RECORDS ARE STANDARD
           VALUE OF FILE-ID IS "OURSTUFF.DAT".
       COPY OURSTUFF.CPY.                                                  
                                                                          
       WORKING-STORAGE SECTION.

       77  FILE-STAT                   PIC  X(02).
                                                                          
       01  COUNTERS.                                                      
           05  RECORDS-WRITTEN         PIC  9(6)           VALUE ZEROES.  
                                                                          
       01  MISC-DATA.                                                     
           05 END-INPUT-FLAG           PIC  X(1)           VALUE SPACES.  
              88 NO-MORE-INPUT                             VALUE 'Y'.     
                                                                          
       PROCEDURE DIVISION.                                                
       A000.                                                              
                                                                          
           OPEN INPUT  MASTER-FILE.                                          
           OPEN OUTPUT OUTPUT-FILE.                                        
                                                                          
           PERFORM R100-START THRU R199-EXIT.
           PERFORM R200-READ-NEXT THRU R299-EXIT.
                                                                          
           PERFORM C100-PROCESS-RECORDS THRU C199-EXIT                    
               UNTIL NO-MORE-INPUT.                                       

           DISPLAY "RECORDS WRITTEN = " RECORDS-WRITTEN.

           CLOSE MASTER-FILE                                                
                 OUTPUT-FILE.                                              
           STOP RUN.                                                      
                                                                          
       C100-PROCESS-RECORDS.

           MOVE  OURSTUFF-RECORD           TO  OUTPUT-RECORD.
           PERFORM S100-WRITE-OUTPUT THRU S199-EXIT.

           ADD  1                          TO  RECORDS-WRITTEN.  

       C180-READ-NEXT.

           PERFORM R200-READ-NEXT THRU R299-EXIT.

       C199-EXIT.

           EXIT.                                                          
                                                                          
                                                                          
                                                                          
       R100-START.

           MOVE  SPACES                    TO  OURSTUFF-KEY.
           START MASTER-FILE       KEY IS NOT LESS THAN OURSTUFF-KEY
               INVALID KEY
                   PERFORM V100-FILE-IO-ERROR THRU V199-EXIT.

       R199-EXIT.

           EXIT.




       R200-READ-NEXT.

           READ MASTER-FILE
               NEXT RECORD.
           IF  FILE-STAT = "10"
               MOVE  "Y" TO END-INPUT-FLAG
               GO TO R299-EXIT.
           IF  FILE-STAT NOT = "00"
               PERFORM V100-FILE-IO-ERROR THRU V199-EXIT.

       R299-EXIT.

           EXIT.




       S100-WRITE-OUTPUT.

           WRITE OUTPUT-RECORD
             INVALID KEY
                 PERFORM V100-FILE-IO-ERROR THRU V199-EXIT.

       S199-EXIT.

           EXIT.




                                                                          
       V100-FILE-IO-ERROR.

           DISPLAY "FILE I/O ERROR ... FILE STATUS = " FILE-STAT.

       V199-EXIT.

           EXIT.
                                                                          
