       IDENTIFICATION DIVISION.                                           
       PROGRAM-ID.     LOADMSTR.                                          
       AUTHOR.         ROGER COLE.                                        
       DATE-WRITTEN.                                                      
       DATE-COMPILED.                                                     
      *REMARKS.                                                           
      *
      *    THIS PROGRAM TAKES A LINE SEQUENTIAL INPUT FILE (SUCH AS
      *    PRODUCED FROM A TEXT EDITOR) AND WRITES THE DATA TO AN
      *    INDEXED MASTER FILE.  SINCE NO SORTING IS DONE WITHIN THIS
      *    PROGRAM, THE INPUT FILE MUST BE IN KEY SEQUENCE.
      *
      *    THIS PROGRAM IS USEFUL FOR QUICKLY LOADING A MASTER FILE
      *    WITHOUT ALREADY HAVING A MAINTENANCE PROGRAM IN PLACE.  IT
      *    CAN ALSO BE USED IN CONJUNCTION WITH THE DUMPMSTR PROGRAM TO
      *    REBUILD A MASTER FILE FROM A BACKUP DUMP FILE.
      *                                                                    
       ENVIRONMENT DIVISION.
       CONFIGURATION SECTION.                                             
       SPECIAL-NAMES.                                                     
       INPUT-OUTPUT SECTION.                                              
       FILE-CONTROL.                                                      
           SELECT INPUT-FILE           ASSIGN TO DISK
                                       ORGANIZATION IS LINE SEQUENTIAL.
           SELECT MASTER-FILE          ASSIGN TO DISK
                                       FILE STATUS IS FILE-STAT
                                       ACCESS MODE IS SEQUENTIAL
                                       ORGANIZATION IS INDEXED
                                       RECORD KEY IS OURSTUFF-KEY.
                                                                          
       DATA DIVISION.                                                     
       FILE SECTION.                                                      
       FD  INPUT-FILE
           LABEL RECORDS ARE STANDARD
           VALUE OF FILE-ID IS "OURSTUFF.INP".
       01  INPUT-RECORD.                                                   
           05  INPUT-KEY.                                              
               10  INPUT-CLASS         PIC  X(03).
               10  INPUT-SEQUENCE      PIC  9(03).
           05  INPUT-LOCATION          PIC  X(12).
           05  INPUT-PURCHASE-DATE     PIC  X(06).
           05  INPUT-PURCHASE-PRICE    PIC  9(06).
           05  INPUT-DESCRIPTION       PIC  X(50).
                                                                          
       FD  MASTER-FILE                                                     
           LABEL RECORDS ARE STANDARD
           VALUE OF FILE-ID IS "OURSTUFF.DAT".
       COPY OURSTUFF.CPY.                                                  
                                                                          
       WORKING-STORAGE SECTION.

       77  FILE-STAT                   PIC  X(02).

       COPY CATEGORY.CPY.

       01  COUNTERS.                                                      
           05  RECORDS-WRITTEN         PIC  9(6)           VALUE ZEROES.  
                                                                          
       01  MISC-DATA.                                                     
           05 END-INPUT-FLAG           PIC  X(1)           VALUE SPACES.  
              88 NO-MORE-INPUT                             VALUE 'Y'.     
                                                                          
       PROCEDURE DIVISION.                                                
       A000.                                                              
                                                                          
           OPEN INPUT INPUT-FILE.                                          
           OPEN OUTPUT MASTER-FILE.                                        
                                                                          
           PERFORM R100-READ-INPUT-FILE THRU R199-EXIT.                    
                                                                          
           PERFORM C100-PROCESS-RECORDS THRU C199-EXIT                    
               UNTIL NO-MORE-INPUT.                                       

           DISPLAY "RECORDS WRITTEN = " RECORDS-WRITTEN.

           CLOSE INPUT-FILE                                                
                 MASTER-FILE.                                              
           STOP RUN.                                                      
                                                                          
       C100-PROCESS-RECORDS.

           SET CAT-IDX                            TO  1.
           SEARCH  CATEGORIES                     VARYING CAT-IDX
               AT END
                   DISPLAY "INVALID KEY CATEGORY " INPUT-KEY
                   GO TO C180-READ-NEXT
               WHEN CATEGORY (CAT-IDX) = INPUT-CLASS
                   NEXT SENTENCE.

           IF  INPUT-SEQUENCE NOT NUMERIC
               DISPLAY "NON-NUMERIC SEQUENCE .. " INPUT-KEY
               GO TO C180-READ-NEXT.

           IF  INPUT-PURCHASE-DATE NOT NUMERIC
               DISPLAY "NON-NUMERIC PURCHASE DATE " INPUT-KEY
               GO TO C180-READ-NEXT.

           IF  INPUT-PURCHASE-PRICE NOT NUMERIC
               DISPLAY "NON-NUMERIC PURCHASE PRICE " INPUT-KEY
               GO TO C180-READ-NEXT.

           MOVE  INPUT-RECORD              TO  OURSTUFF-RECORD.
           WRITE OURSTUFF-RECORD.

           IF  FILE-STAT NOT = "00"
               PERFORM V100-FILE-IO-ERROR THRU V199-EXIT
               MOVE 'Y'              TO END-INPUT-FLAG
               GO TO C199-EXIT.

           ADD  1                          TO  RECORDS-WRITTEN.  

       C180-READ-NEXT.

           PERFORM R100-READ-INPUT-FILE THRU R199-EXIT.

       C199-EXIT.

           EXIT.                                                          
                                                                          
                                                                          
                                                                          
                                                                          
       R100-READ-INPUT-FILE.

            READ INPUT-FILE                                                
            AT END                                                        
               MOVE 'Y'              TO END-INPUT-FLAG                     
               GO TO R199-EXIT.                                           
                                                                          
       R199-EXIT.

           EXIT.



       V100-FILE-IO-ERROR.

           DISPLAY "FILE I/O ERROR ... FILE STATUS = " FILE-STAT.

       V199-EXIT.

           EXIT.
                                                                          
